## Graph2d | Performance

This example is a test of the performance of the Graph2d. Select the amount of datapoints you want to plot and press draw. You can choose between the style of the points as well as the interpolation method. This can only be toggled with the buttons. The interpolation options may not look different for this dataset but you can see their effects clearly in example 7.
Linear interpolation and no points are the settings that will render quickest. By default, Graph2d will downsample when there are more than 1 point per pixel. This can be manually disabled at the cost of performance by using the `sampling` option.

Number of items: Click the draw button to load the data!
Interpolation method:
Points style: